@@ -26,10 +26,25 @@
 #' of the column names. The validation function can be used directly on a data
 #' table or with an *agent* object (technically, a `ptblank_agent` object)
 #' whereas the expectation and test functions can only be used with a data
-#' table. The types of data tables that can be used include data frames,
-#' tibbles, database tables (`tbl_dbi`), and Spark DataFrames (`tbl_spark`).
-#' Each validation step or expectation will operate over a single test unit,
-#' which is whether the column exists or not.
+#' table. Each validation step or expectation will operate over a single test
+#' unit, which is whether the column exists or not.
+#' 
+#' @section Supported Input Tables:
+#' The types of data tables that are officially supported are:
+#' 
+#'  - data frames (`data.frame`) and tibbles (`tbl_df`)
+#'  - Spark DataFrames (`tbl_spark`)
+#'  - the following database tables (`tbl_dbi`):
+#'    - *PostgreSQL* tables (using the `RPostgres::Postgres()` as driver)
+#'    - *MySQL* tables (with `RMySQL::MySQL()`)
+#'    - *Microsoft SQL Server* tables (via **odbc**)
+#'    - *BigQuery* tables (using `bigrquery::bigquery()`)
+#'    - *DuckDB* tables (through `duckdb::duckdb()`)
+#'    - *SQLite* (with `RSQLite::SQLite()`)
+#'    
+#' Other database tables may work to varying degrees but they haven't been
+#' formally tested (so be mindful of this when using unsupported backends with
+#' **pointblank**).
 #'
 #' @section Column Names:
 #' If providing multiple column names, the result will be an expansion of
@@ -68,17 +83,21 @@
 #' validation step is expressed in R code and in the corresponding YAML
 #' representation.
 #' 
-#' ```
-#' # R statement
+#' R statement:
+#' 
+#' ```r
 #' agent %>% 
 #'   col_exists(
-#'     vars(a),
+#'     columns = vars(a),
 #'     actions = action_levels(warn_at = 0.1, stop_at = 0.2),
 #'     label = "The `col_exists()` step.",
 #'     active = FALSE
 #'   )
+#' ```
 #' 
-#' # YAML representation
+#' YAML representation:
+#' 
+#' ```yaml
 #' steps:
 #' - col_exists:
 #'     columns: vars(a)
@@ -108,65 +127,71 @@
 #'   called primarily for its potential side-effects (e.g., signaling failure).
 #'   The test function returns a logical value.
 #'   
-#' @examples
-#' # For all examples here, we'll use
-#' # a simple table with two columns:
-#' # `a` and `b`
+#' @section Examples:
+#' 
+#' For all examples here, we'll use a simple table with two columns: `a` and
+#' `b`.
+#' 
+#' ```{r}
 #' tbl <-
 #'   dplyr::tibble(
 #'     a = c(5, 7, 6, 5, 8, 7),
 #'     b = c(7, 1, 0, 0, 0, 3)
 #'   )
+#'   
+#' tbl
+#' ```
 #' 
-#' # A: Using an `agent` with validation
-#' #    functions and then `interrogate()`
+#' We'll use this table with the different function variants.
 #' 
-#' # Validate that columns `a` and `b`
-#' # exist in the `tbl` table; this
-#' # makes two distinct validation
-#' # steps since two columns were
-#' # provided to `vars()`
+#' ## A: Using an `agent` with validation functions and then `interrogate()`
+#' 
+#' Validate that column `a` exists in the `tbl` table with `col_exists()`.
+#' 
+#' ```r
 #' agent <-
-#'   create_agent(tbl) %>%
-#'   col_exists(vars(a, b)) %>%
+#'   create_agent(tbl = tbl) %>%
+#'   col_exists(columns = vars(a)) %>%
 #'   interrogate()
+#' ```
 #' 
-#' # Determine if this validation
-#' # had no failing test units (1)
-#' all_passed(agent)
+#' Printing the `agent` in the console shows the validation report in the
+#' Viewer. Here is an excerpt of validation report, showing the single entry
+#' that corresponds to the validation step demonstrated here.
 #' 
-#' # Calling `agent` in the console
-#' # prints the agent's report; but we
-#' # can get a `gt_tbl` object directly
-#' # with `get_agent_report(agent)`
+#' \if{html}{
+#' \out{
+#' `r pb_get_image_tag(file = "man_col_exists_1.png")`
+#' }
+#' }
 #' 
-#' # B: Using the validation function
-#' #    directly on the data (no `agent`)
+#' ## B: Using the validation function directly on the data (no `agent`)
 #' 
-#' # This way of using validation functions
-#' # acts as a data filter: data is passed
-#' # through but should `stop()` if there
-#' # is a single test unit failing; the
-#' # behavior of side effects can be
-#' # customized with the `actions` option
-#' tbl %>% col_exists(vars(a, b))
+#' This way of using validation functions acts as a data filter. Data is
+#' passed through but should `stop()` if there is a single test unit failing.
+#' The behavior of side effects can be customized with the `actions` option.
 #' 
-#' # C: Using the expectation function
+#' ```{r}
+#' tbl %>% col_exists(columns = vars(a))
+#' ```
 #' 
-#' # With the `expect_*()` form, we need
-#' # to be more exacting and provide one
-#' # column at a time; this is primarily
-#' # used in testthat tests
-#' expect_col_exists(tbl, vars(a))
-#' expect_col_exists(tbl, vars(b))
+#' ## C: Using the expectation function
 #' 
-#' # D: Using the test function
+#' With the `expect_*()` form, we would typically perform one validation at a
+#' time. This is primarily used in **testthat** tests.
 #' 
-#' # With the `test_*()` form, we should
-#' # get a single logical value returned
-#' # to us (even if there are multiple
-#' # columns tested, as is the case below)
-#' tbl %>% test_col_exists(vars(a, b))
+#' ```r
+#' expect_col_exists(tbl, columns = vars(a))
+#' ```
+#' 
+#' ## D: Using the test function
+#' 
+#' With the `test_*()` form, we should get a single logical value returned to
+#' us.
+#' 
+#' ```{r}
+#' tbl %>% test_col_exists(columns = vars(a))
+#' ```
 #' 
 #' @family validation functions
 #' @section Function ID:
@@ -178,13 +203,15 @@ NULL
 #' @rdname col_exists
 #' @import rlang
 #' @export
-col_exists <- function(x,
-                       columns,
-                       actions = NULL,
-                       step_id = NULL,
-                       label = NULL,
-                       brief = NULL,
-                       active = TRUE) {
+col_exists <- function(
+    x,
+    columns,
+    actions = NULL,
+    step_id = NULL,
+    label = NULL,
+    brief = NULL,
+    active = TRUE
+) {
 
   preconditions <- NULL
   values <- NULL
@@ -265,9 +292,11 @@ col_exists <- function(x,
 #' @rdname col_exists
 #' @import rlang
 #' @export
-expect_col_exists <- function(object,
-                              columns,
-                              threshold = 1) {
+expect_col_exists <- function(
+    object,
+    columns,
+    threshold = 1
+) {
 
   fn_name <- "expect_col_exists"
   
@@ -335,9 +364,11 @@ expect_col_exists <- function(object,
 #' @rdname col_exists
 #' @import rlang
 #' @export
-test_col_exists <- function(object,
-                            columns,
-                            threshold = 1) {
+test_col_exists <- function(
+    object,
+    columns,
+    threshold = 1
+) {
   
   vs <- 
     create_agent(tbl = object, label = "::QUIET::") %>%
