@@ -69,74 +69,164 @@
 #' @return A list of table objects if `type` is `NULL`, or, a single table if a
 #'   `type` is given.
 #' 
-#' @examples
-#' # Create a series of two validation
-#' # steps focused on testing row values
-#' # for part of the `small_table` object;
-#' # `interrogate()` immediately
+#' @section Examples:
+#' 
+#' Create a series of two validation steps focused on testing row values for
+#' part of the `small_table` object. Then, use [interrogate()] to put the
+#' validation plan into action.
+#' 
+#' ```r
 #' agent <-
 #'   create_agent(
 #'     tbl = small_table %>%
 #'       dplyr::select(a:f),
 #'     label = "`get_sundered_data()`"
 #'   ) %>%
-#'   col_vals_gt(vars(d), value = 1000) %>%
+#'   col_vals_gt(columns = vars(d), value = 1000) %>%
 #'   col_vals_between(
-#'     vars(c),
+#'     columns = vars(c),
 #'     left = vars(a), right = vars(d),
 #'     na_pass = TRUE
 #'   ) %>%
 #'   interrogate()
+#' ```
 #' 
-#' # Get the sundered data piece that
-#' # contains only rows that passed both
-#' # validation steps (the default piece);
-#' # this yields 5 of 13 total rows
+#' Get the sundered data piece that contains only rows that passed both
+#' validation steps (the default piece). This yields 5 of 13 total rows.
+#' 
+#' ```r
 #' agent %>% get_sundered_data()
+#' ```
+#' 
+#' \preformatted{## # A tibble: 5 × 6
+#' ##       a b             c      d e     f    
+#' ##   <int> <chr>     <dbl>  <dbl> <lgl> <chr>
+#' ## 1     2 1-bcd-345     3  3423. TRUE  high 
+#' ## 2     3 5-egh-163     8 10000. TRUE  low  
+#' ## 3     2 5-jdo-903    NA  3892. FALSE mid  
+#' ## 4     4 2-dhe-923     4  3291. TRUE  mid  
+#' ## 5     1 3-dka-303    NA  2230. TRUE  high}
+#' 
+#' 
+#' 
+#' Get the complementary data piece: all of those rows that failed either of the
+#' two validation steps. This yields 8 of 13 total rows.
+#' 
+#' ```r
+#' agent %>% get_sundered_data(type = "fail")
+#' ```
+#' 
+#' \preformatted{## # A tibble: 8 × 6
+#' ##       a b             c     d e     f    
+#' ##   <int> <chr>     <dbl> <dbl> <lgl> <chr>
+#' ## 1     6 8-kdg-938     3 2343. TRUE  high 
+#' ## 2     8 3-ldm-038     7  284. TRUE  low  
+#' ## 3     7 1-knw-093     3  843. TRUE  high 
+#' ## 4     4 5-boe-639     2 1036. FALSE low  
+#' ## 5     3 5-bce-642     9  838. FALSE high 
+#' ## 6     3 5-bce-642     9  838. FALSE high 
+#' ## 7     4 2-dmx-010     7  834. TRUE  low  
+#' ## 8     2 7-dmx-010     8  108. FALSE low}
+#' 
 #' 
-#' # Get the complementary data piece:
-#' # all of those rows that failed either
-#' # of the two validation steps;
-#' # this yields 8 of 13 total rows
-#' agent %>%
-#'   get_sundered_data(type = "fail")
 #'   
-#' # We can get all of the input data
-#' # returned with a flag column (called
-#' # `.pb_combined`); this is done by
-#' # using `type = "combined"` and that
-#' # rightmost column will contain `"pass"`
-#' # and `"fail"` values
-#' agent %>%
-#'   get_sundered_data(type = "combined")
+#' We can get all of the input data returned with a flag column (called
+#' `.pb_combined`). This is done by using `type = "combined"` and that rightmost
+#' column will contain `"pass"` and `"fail"` values.
 #' 
-#' # We can change the `"pass"` or `"fail"`
-#' # text values to another type of coding
-#' # with the `pass_fail` argument; one
-#' # possibility is TRUE/FALSE
+#' ```r
+#' agent %>% get_sundered_data(type = "combined")
+#' ```
+#' 
+#' \preformatted{## # A tibble: 13 × 7
+#' ##        a b             c      d e     f     .pb_combined
+#' ##    <int> <chr>     <dbl>  <dbl> <lgl> <chr> <chr>
+#' ##  1     2 1-bcd-345     3  3423. TRUE  high  pass
+#' ##  2     3 5-egh-163     8 10000. TRUE  low   pass
+#' ##  3     6 8-kdg-938     3  2343. TRUE  high  fail
+#' ##  4     2 5-jdo-903    NA  3892. FALSE mid   pass
+#' ##  5     8 3-ldm-038     7   284. TRUE  low   fail
+#' ##  6     4 2-dhe-923     4  3291. TRUE  mid   pass
+#' ##  7     7 1-knw-093     3   843. TRUE  high  fail
+#' ##  8     4 5-boe-639     2  1036. FALSE low   fail
+#' ##  9     3 5-bce-642     9   838. FALSE high  fail
+#' ## 10     3 5-bce-642     9   838. FALSE high  fail
+#' ## 11     4 2-dmx-010     7   834. TRUE  low   fail
+#' ## 12     2 7-dmx-010     8   108. FALSE low   fail
+#' ## 13     1 3-dka-303    NA  2230. TRUE  high  pass}
+#' 
+#' 
+#' 
+#' We can change the `"pass"` or `"fail"` text values to another type of coding
+#' with the `pass_fail` argument. One possibility is `TRUE`/`FALSE`.
+#' 
+#' ```r
 #' agent %>%
 #'   get_sundered_data(
 #'     type = "combined",
 #'     pass_fail = c(TRUE, FALSE)
 #'   )
+#' ```
+#' 
+#' \preformatted{## # A tibble: 13 × 7
+#' ##        a b             c      d e     f     .pb_combined
+#' ##    <int> <chr>     <dbl>  <dbl> <lgl> <chr> <lgl>
+#' ##  1     2 1-bcd-345     3  3423. TRUE  high  TRUE
+#' ##  2     3 5-egh-163     8 10000. TRUE  low   TRUE
+#' ##  3     6 8-kdg-938     3  2343. TRUE  high  FALSE
+#' ##  4     2 5-jdo-903    NA  3892. FALSE mid   TRUE
+#' ##  5     8 3-ldm-038     7   284. TRUE  low   FALSE
+#' ##  6     4 2-dhe-923     4  3291. TRUE  mid   TRUE
+#' ##  7     7 1-knw-093     3   843. TRUE  high  FALSE
+#' ##  8     4 5-boe-639     2  1036. FALSE low   FALSE
+#' ##  9     3 5-bce-642     9   838. FALSE high  FALSE
+#' ## 10     3 5-bce-642     9   838. FALSE high  FALSE
+#' ## 11     4 2-dmx-010     7   834. TRUE  low   FALSE
+#' ## 12     2 7-dmx-010     8   108. FALSE low   FALSE
+#' ## 13     1 3-dka-303    NA  2230. TRUE  high  TRUE}
 #'
-#' # ...and using `0` and `1` might be
-#' # worthwhile in some situations
+#'
+#'
+#' ...and using `0` and `1` might be worthwhile in some situations.
+#' 
+#' ```r
 #' agent %>%
 #'   get_sundered_data(
 #'     type = "combined",
 #'     pass_fail = 0:1
 #'   )
+#' ```
+#' 
+#' \preformatted{## # A tibble: 13 × 7
+#' ##        a b             c      d e     f     .pb_combined
+#' ##    <int> <chr>     <dbl>  <dbl> <lgl> <chr>        <int>
+#' ##  1     2 1-bcd-345     3  3423. TRUE  high             0
+#' ##  2     3 5-egh-163     8 10000. TRUE  low              0
+#' ##  3     6 8-kdg-938     3  2343. TRUE  high             1
+#' ##  4     2 5-jdo-903    NA  3892. FALSE mid              0
+#' ##  5     8 3-ldm-038     7   284. TRUE  low              1
+#' ##  6     4 2-dhe-923     4  3291. TRUE  mid              0
+#' ##  7     7 1-knw-093     3   843. TRUE  high             1
+#' ##  8     4 5-boe-639     2  1036. FALSE low              1
+#' ##  9     3 5-bce-642     9   838. FALSE high             1
+#' ## 10     3 5-bce-642     9   838. FALSE high             1
+#' ## 11     4 2-dmx-010     7   834. TRUE  low              1
+#' ## 12     2 7-dmx-010     8   108. FALSE low              1
+#' ## 13     1 3-dka-303    NA  2230. TRUE  high             0}
+#' 
+#' 
 #' 
 #' @family Post-interrogation
 #' @section Function ID:
 #' 8-3
 #' 
 #' @export
-get_sundered_data <- function(agent,
-                              type = c("pass", "fail", "combined"),
-                              pass_fail = c("pass", "fail"),
-                              id_cols = NULL) {
+get_sundered_data <- function(
+    agent,
+    type = c("pass", "fail", "combined"),
+    pass_fail = c("pass", "fail"),
+    id_cols = NULL
+) {
 
   # Match to one of the three choices (`pass`, `fail`, `combined`)
   # while still allowing for the NULL optiona
