@@ -15,6 +15,7 @@ structure(list(table_name = c("alt_allele", "analysis", "analysis_description",
 "splicing_event", "splicing_event_feature", "splicing_transcript_pair", 
 "stable_id_event", "supporting_feature", "transcript", "transcript_attrib", 
 "transcript_stable_id", "transcript_supporting_feature", "translation", 
-"translation_attrib", "translation_stable_id", "unconventional_transcript_association", 
-"unmapped_object", "unmapped_reason", "xref")), class = "data.frame", row.names = c(NA, 
--75L))
+"translation_attrib", "translation_stable_id",
+"unconventional_transcript_association", 
+"unmapped_object", "unmapped_reason", "xref")),
+class = "data.frame", row.names = c(NA, -75L))
